utils::globalVariables(c("ENTRY",
                         "IBLOCK",
                         "REP",
                         "ROW",
                         "COLUMN",
                         "TREATMENT",
                         "LOCATION",
                         "PLOT", 
                         "SQUARE",
                         "SUB_PLOT",
                         "SUB_SUB_PLOT",
                         "TRT_COMB",
                         "WHOLE_PLOT",
                         "text", 
                         "BLOCK", 
                         "CHECKS", 
                         "EXPT",
                         "Level_1",
                         "Level_2",
                         "dif",
                         "treatments",
                         "NAME",
                         "REPS",
                         "loc",
                         "copies",
                         ".",
                         "Copies",
                         "sparse_entry",
                         "USER_ENTRY",
                         "NAME.x",
                         "NAME.y",
                         "Times", 
                         "all_consecutive", 
                         "are_consecutive", 
                         "plots", "arcbd_plot", "new_order_treatments", 
                         "LABEL_TREATMENT",
                         "Level", 
                         "Level_3", "ID", "YEAR", "IS_CHECK", "PLOT_TXT"))
